( cd usr/lib ; rm -rf libgucharmap.so.4 )
( cd usr/lib ; ln -sf libgucharmap.so.4.0.3 libgucharmap.so.4 )
( cd usr/lib ; rm -rf libgucharmap.so )
( cd usr/lib ; ln -sf libgucharmap.so.4.0.3 libgucharmap.so )
( cd usr/bin ; rm -rf charmap )
( cd usr/bin ; ln -sf gucharmap charmap )
( cd usr/bin ; rm -rf gnome-character-map )
( cd usr/bin ; ln -sf gucharmap gnome-character-map )
